SystemOrganization addCategory: #'Obj1-preguntados'!
SystemOrganization addCategory: 'Obj1-preguntados-model'!
SystemOrganization addCategory: 'Obj1-preguntados-specs'!

TestCase subclass: #TestCategoria
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Obj1-preguntados-specs'!

!TestCategoria methodsFor: 'as yet unclassified' stamp: 'FedericoAloi 11/18/2015 16:40'!
test_SiguientePreguntaFallaSiNoHayMasPreguntas
	|categoria pregunta|
	pregunta := Pregunta new.
	categoria := Categoria conPreguntas: { pregunta }.
	
	categoria siguientePregunta.

	self should: [categoria siguientePregunta] raise: Error whoseDescriptionIncludes: 'No quedan más preguntas en esta categoría' description: ''! !

!TestCategoria methodsFor: 'as yet unclassified' stamp: 'FedericoAloi 11/18/2015 12:30'!
test_SiguientePreguntaQuitaLaPreguntaDeLaCategoria
	|categoria pregunta1 pregunta2 siguiente|
	pregunta1 := Pregunta new.
	pregunta2 := Pregunta new.
	categoria := Categoria conPreguntas: { pregunta1. pregunta2 }.
	
	siguiente := categoria siguientePregunta.
	
	self deny: (categoria preguntas includes: siguiente)! !

TestCase subclass: #TestPreguntados
	instanceVariableNames: 'jugadorDesafiante otroJugador partida preguntaHistoria respuestaCorrecta preguntaHistoriaHelicoptero'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Obj1-preguntados-specs'!

!TestPreguntados methodsFor: 'helpers' stamp: 'FedericoAloi 11/24/2015 19:46'!
contestarBienPreguntaActual	
	| turno pregunta |
	turno := partida turnoActual.
	pregunta := turno pregunta.
	turno responderPreguntaCon: turno pregunta respuestaCorrecta.
	
	^ pregunta! !

!TestPreguntados methodsFor: 'helpers' stamp: 'FedericoAloi 11/24/2015 23:46'!
contestarMalPreguntaActual
	| turno |
	turno := partida turnoActual.
	turno responderPreguntaCon: (preguntaHistoria algunaRespuestaIncorrecta).
	
	^turno
	! !

!TestPreguntados methodsFor: 'running' stamp: 'FedericoAloi 11/25/2015 00:10'!
setUp
	jugadorDesafiante := Jugador llamado: 'Fede'.
	otroJugador := Jugador llamado: 'Ari'.
	
	preguntaHistoria := Pregunta 
		texto: '¿En qué año fue proscripto el Peronismo?'
		respuestaCorrecta: '1955'
		eIncorrecta: '1954'
		eIncorrecta: '1956'
		eIncorrecta: '1953'.
		
	preguntaHistoriaHelicoptero := Pregunta 
			texto: '¿Qué presidente de la República Argentina terminó su mandato tras abandonar la Casa Rosada en helicóptero?'
			respuestaCorrecta: 'Fernando de la Rúa'
			eIncorrecta: 'Hector Cámpora'
			eIncorrecta: 'Néstor Kirchner'
			eIncorrecta: 'Eduardo Duhalde'.
		
	Categoria conPreguntasDeHistoria: { 
		preguntaHistoria. 
		Pregunta 
			texto: 'De las siguientes personas, ¿quién nunca ganó el Premio Nobel de la Paz?'
			respuestaCorrecta: 'Carlitos Balá'
			eIncorrecta: 'Barack Obama'
			eIncorrecta: 'Rigoberta Menchú'
			eIncorrecta: 'Adolfo Pérez Esquivel'. 
		Pregunta 
			texto: '¿En qué ciudad japonesa cayó la primera bomba atómica, arrojada durante la Segunda Guerra Mundial?'
			respuestaCorrecta: 'Hiroshima'
			eIncorrecta: 'Nagasaki'
			eIncorrecta: 'Tokio'
			eIncorrecta: 'Yokohama'. 
		preguntaHistoriaHelicoptero.
		Pregunta 
			texto: '¿En qué año tuvo lugar el ataque a Pearl Harbor?'
			respuestaCorrecta: '1941'
			eIncorrecta: '1939'
			eIncorrecta: '1940'
			eIncorrecta: '1942'. 		
	}.
	
	partida := Partida con: jugadorDesafiante desafiaA: otroJugador yCategorias: Categoria todas! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/25/2015 00:12'!
test_AlComenzarUnTurnoElMismoSeEncuentraEnLaEtapaDeGiroDeRuleta
	self assert: partida turnoActual etapa equals: EtapaGiroDeRuleta! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/24/2015 23:27'!
test_AlContestarBienLaPreguntaSeEligeOtraPregunta
	| preguntaRespondidaCorrectamente |
	preguntaRespondidaCorrectamente := self contestarBienPreguntaActual.
	self deny: partida turnoActual pregunta = preguntaRespondidaCorrectamente! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/25/2015 00:13'!
test_AlContestarBienLaPreguntaSeSumaUnPuntoAlTurno
	self contestarBienPreguntaActual.
	self assert: EtapaGiroDeRuleta puntaje equals: 1! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/19/2015 16:57'!
test_AlContestarMalLaPreguntaCambiaElTurno
	| turnoAnterior |
	turnoAnterior := self contestarMalPreguntaActual.	
		
	self deny: (turnoAnterior = partida turnoActual)! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/19/2015 16:57'!
test_AlContestarMalLaPreguntaElNuevoTurnoEsDelOtroJugador
	| turnoAnterior |
	turnoAnterior := self contestarMalPreguntaActual.	
		
	self assert: (partida turnoActual jugadorActual) equals: (turnoAnterior jugadorSiguiente)! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/25/2015 00:13'!
test_AlContestarMalLaPreguntaNoSumaPuntosAlTurno
	| turnoAnterior |
	turnoAnterior := self contestarMalPreguntaActual.	
		
	self assert: EtapaGiroDeRuleta puntaje equals: 0.! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/24/2015 23:28'!
test_AlIniciarUnTurnoEnEtapaGiroLaPreguntaEstaEstablecida
	self assert: partida turnoActual pregunta equals: preguntaHistoria! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/18/2015 10:14'!
test_AlIniciarseUnaPartidaElPrimerTurnoCorrespondeAlJugadorDesafiante
	self assert: partida turnoActual jugador equals: jugadorDesafiante! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/25/2015 00:13'!
test_ContestarCorrectamenteLaPreguntaDeObtencionDeCoronaOtorgaLaCorona
	3 timesRepeat: [ self contestarBienPreguntaActual ].	
	EtapaObtencionDeCorona elegirCategoria: (Categoria historia).
	
	self contestarBienPreguntaActual.

	self assert: jugadorDesafiante coronas asArray equals: { Categoria historia }! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/25/2015 00:13'!
test_ContestarCorrectamenteLaPreguntaDeObtencionDeCoronaVuelveElTurnoAlGiroDeRuleta
	3 timesRepeat: [ self contestarBienPreguntaActual ].	
	EtapaObtencionDeCorona elegirCategoria: (Categoria historia).
	
	self contestarBienPreguntaActual.

	self assert: partida turnoActual etapa equals: EtapaGiroDeRuleta! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/25/2015 00:13'!
test_ElegirCategoriaEnEtapaObtencionDeCoronaConfiguraLaSiguientePregunta
	3 timesRepeat: [ self contestarBienPreguntaActual ].	
	EtapaObtencionDeCorona elegirCategoria: (Categoria historia).

	self assert: partida turnoActual etapa pregunta equals: preguntaHistoriaHelicoptero ! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/24/2015 23:28'!
test_PedirLaSiguientePreguntaEnObtencionDeCoronaFallaSiNoSeEligioLaCategoria
	3 timesRepeat: [ self contestarBienPreguntaActual ].
	
	self
		should: [ partida turnoActual pregunta ]
		raise: Error
		whoseDescriptionIncludes: 'Aún no se ha seleccionado la corona por la cual se desea participar'
		description: ''! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/25/2015 00:13'!
test_TrasContestar3PreguntasCorrectamenteSeAvanzaAEtapaDeCorona
	3 timesRepeat: [ self contestarBienPreguntaActual ].
	self assert: partida turnoActual etapa equals: EtapaObtencionDeCorona! !

!TestPreguntados methodsFor: 'tests' stamp: 'FedericoAloi 11/18/2015 10:14'!
test_UnJugadorPuedeIniciarUnaPartidaDesafiandoAOtroJugador
	self assert: partida estaIniciada

! !

Object subclass: #Categoria
	instanceVariableNames: 'preguntas'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Obj1-preguntados-model'!

Categoria class
	instanceVariableNames: 'historia'!

Categoria class
	instanceVariableNames: 'historia'!

!Categoria class methodsFor: 'initialization' stamp: 'FedericoAloi 11/18/2015 11:57'!
conPreguntas: unasPreguntas 
	^(self new) conPreguntas: unasPreguntas ; yourself! !

!Categoria class methodsFor: 'initialization' stamp: 'FedericoAloi 11/18/2015 11:57'!
conPreguntasDeHistoria: preguntasHistoria 
	historia := self conPreguntas: preguntasHistoria! !

!Categoria class methodsFor: 'accessors' stamp: 'FedericoAloi 11/24/2015 23:43'!
historia
	^ historia! !

!Categoria class methodsFor: 'public' stamp: 'FedericoAloi 11/18/2015 11:58'!
todas
	^{historia}! !

!Categoria methodsFor: 'initialization' stamp: 'FedericoAloi 11/19/2015 17:09'!
conPreguntas: unasPreguntas
	preguntas := OrderedCollection new.
	preguntas addAll: unasPreguntas! !

!Categoria methodsFor: 'accessors' stamp: 'FedericoAloi 11/18/2015 12:24'!
preguntas
	^ preguntas! !

!Categoria methodsFor: 'public' stamp: 'FedericoAloi 11/19/2015 17:09'!
siguientePregunta
	|siguiente|
	self validarQuedanPreguntas.	
	siguiente := preguntas first.
	preguntas remove: siguiente.
	^siguiente! !

!Categoria methodsFor: 'private' stamp: 'FedericoAloi 11/18/2015 16:39'!
validarQuedanPreguntas
	self preguntas ifEmpty: [self error: 'No quedan más preguntas en esta categoría']! !

Object subclass: #Etapa
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Obj1-preguntados-model'!

Etapa class
	instanceVariableNames: 'pregunta'!

!Etapa commentStamp: '<historical>' prior: 0!
Soy una etapa de juego. Denoto el estado del juego en un momento dado.!

Etapa class
	instanceVariableNames: 'pregunta'!

!Etapa class methodsFor: 'public' stamp: 'FedericoAloi 11/24/2015 22:49'!
pregunta
	^ pregunta ifNil: [ self preguntaNoEstablecida ]! !

!Etapa class methodsFor: 'initialization' stamp: 'FedericoAloi 11/24/2015 23:22'!
reiniciarPara: unTurno
	pregunta := nil! !

Etapa subclass: #EtapaGiroDeRuleta
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Obj1-preguntados-model'!

EtapaGiroDeRuleta class
	instanceVariableNames: 'puntaje'!

!EtapaGiroDeRuleta commentStamp: '<historical>' prior: 0!
Soy la etapa en la cual el jugador debe girar la ruleta!

EtapaGiroDeRuleta class
	instanceVariableNames: 'puntaje'!

!EtapaGiroDeRuleta class methodsFor: 'public' stamp: 'FedericoAloi 11/25/2015 00:13'!
avanzarEn: unTurno 
	(self etapaTerminadaPara: unTurno) 
		ifTrue: [ unTurno cambiarEtapaA: EtapaObtencionDeCorona ]
		ifFalse: [ self avanzarEnEtapaPara: unTurno ]! !

!EtapaGiroDeRuleta class methodsFor: 'private' stamp: 'FedericoAloi 11/24/2015 23:19'!
avanzarEnEtapaPara: unTurno
	self siguientePreguntaEn: unTurno.
	puntaje := puntaje + 1! !

!EtapaGiroDeRuleta class methodsFor: 'private' stamp: 'FedericoAloi 11/24/2015 23:34'!
etapaTerminadaPara: unTurno 
	^ puntaje = (self puntajeMaximoEtapa - 1)! !

!EtapaGiroDeRuleta class methodsFor: 'public' stamp: 'FedericoAloi 11/24/2015 21:46'!
preguntaNoEstablecida
	^ self error: 'Aún no se ha sorteado la pregunta'! !

!EtapaGiroDeRuleta class methodsFor: 'accessors' stamp: 'FedericoAloi 11/24/2015 23:03'!
puntaje
	^ puntaje! !

!EtapaGiroDeRuleta class methodsFor: 'constants' stamp: 'FedericoAloi 11/24/2015 19:55'!
puntajeMaximoEtapa
	^3! !

!EtapaGiroDeRuleta class methodsFor: 'initialization' stamp: 'FedericoAloi 11/24/2015 23:21'!
reiniciarPara: unTurno
	super reiniciarPara: unTurno.
	self siguientePreguntaEn: unTurno.
	puntaje := 0! !

!EtapaGiroDeRuleta class methodsFor: 'private' stamp: 'FedericoAloi 11/24/2015 23:19'!
siguientePreguntaEn: unTurno
	pregunta := self sortearPreguntaPara: unTurno! !

!EtapaGiroDeRuleta class methodsFor: 'private' stamp: 'FedericoAloi 11/24/2015 21:28'!
sortearCategoriaPara: unTurno 
	^unTurno categorias anyOne! !

!EtapaGiroDeRuleta class methodsFor: 'private' stamp: 'FedericoAloi 11/24/2015 21:29'!
sortearPreguntaPara: unTurno 
	^(self sortearCategoriaPara: unTurno) siguientePregunta! !

Etapa subclass: #EtapaObtencionDeCorona
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Obj1-preguntados-model'!

EtapaObtencionDeCorona class
	instanceVariableNames: 'categoriaElegida'!

EtapaObtencionDeCorona class
	instanceVariableNames: 'categoriaElegida'!

!EtapaObtencionDeCorona class methodsFor: 'public' stamp: 'FedericoAloi 11/25/2015 00:12'!
avanzarEn: unTurno
	unTurno jugadorActual coronaGanada: categoriaElegida.
	unTurno cambiarEtapaA: EtapaGiroDeRuleta! !

!EtapaObtencionDeCorona class methodsFor: 'public' stamp: 'FedericoAloi 11/25/2015 00:00'!
elegirCategoria: unaCategoria 
	categoriaElegida := unaCategoria.
	pregunta := unaCategoria siguientePregunta ! !

!EtapaObtencionDeCorona class methodsFor: 'public' stamp: 'FedericoAloi 11/24/2015 21:47'!
preguntaNoEstablecida
	^ self error: 'Aún no se ha seleccionado la corona por la cual se desea participar'! !

Object subclass: #Jugador
	instanceVariableNames: 'nombre coronas'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Obj1-preguntados-model'!

!Jugador commentStamp: '<historical>' prior: 0!
Soy un jugador del juego Preguntados!

!Jugador class methodsFor: 'as yet unclassified' stamp: 'FedericoAloi 11/19/2015 17:19'!
llamado: unNombre
	^(self new) conNombre: unNombre ; yourself! !

!Jugador methodsFor: 'initializers' stamp: 'FedericoAloi 11/19/2015 17:22'!
conNombre: unNombre
	nombre := unNombre! !

!Jugador methodsFor: 'public' stamp: 'FedericoAloi 11/24/2015 23:58'!
coronaGanada: unaCategoria
	coronas add: unaCategoria! !

!Jugador methodsFor: 'accessors' stamp: 'FedericoAloi 11/24/2015 23:59'!
coronas
	^ coronas! !

!Jugador methodsFor: 'public' stamp: 'ArielAlvarez 10/27/2015 21:24'!
desafiaA: otroJugador 
	^Partida newConDesafiante: self yDesafiado: otroJugador! !

!Jugador methodsFor: 'initializers' stamp: 'FedericoAloi 11/24/2015 23:58'!
initialize
	coronas := Bag new! !

Object subclass: #Partida
	instanceVariableNames: 'desafiante desafiado turno categorias'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Obj1-preguntados-model'!

!Partida commentStamp: '<historical>' prior: 0!
Soy una partida de preguntados!

!Partida class methodsFor: 'initialization' stamp: 'FedericoAloi 11/18/2015 12:01'!
con: desafiante desafiaA: contrincante yCategorias: categorias
	^(self new) inicializarConDesafiante: desafiante contra: contrincante yCategorias: categorias ; yourself! !

!Partida methodsFor: 'accessors' stamp: 'FedericoAloi 11/18/2015 12:09'!
categorias
	^ categorias! !

!Partida methodsFor: 'public' stamp: 'ArielAlvarez 10/27/2015 21:25'!
estaIniciada
	^true! !

!Partida methodsFor: 'initialization' stamp: 'FedericoAloi 11/19/2015 16:43'!
inicializarConDesafiante: unJugador contra: otroJugador yCategorias: unasCategorias
	desafiante := unJugador.
	desafiado := otroJugador.
	categorias := Bag new.
	categorias addAll: unasCategorias.
	self nuevoTurnoEntre: unJugador y: otroJugador.
	^self! !

!Partida methodsFor: 'public' stamp: 'ArielAlvarez 10/27/2015 21:40'!
jugador
	self shouldBeImplemented.! !

!Partida methodsFor: 'private' stamp: 'FedericoAloi 11/19/2015 16:44'!
nuevoTurnoEntre: unJugador y: otroJugador
	turno := (Turno new) inicializarConActual: unJugador ySiguiente: otroJugador enPartida: self! !

!Partida methodsFor: 'public' stamp: 'FedericoAloi 11/19/2015 16:46'!
siguienteTurno
	self nuevoTurnoEntre: (turno jugadorSiguiente) y: (turno jugadorActual)! !

!Partida methodsFor: 'public' stamp: 'AlvarezAriel 11/17/2015 22:36'!
turnoActual
	^turno
! !

Object subclass: #Pregunta
	instanceVariableNames: 'texto respuestas'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Obj1-preguntados-model'!

!Pregunta class methodsFor: 'as yet unclassified' stamp: 'FedericoAloi 11/18/2015 16:48'!
texto: unTexto respuestaCorrecta: textoCorrecta eIncorrecta: textoIncorrecta1 eIncorrecta: textoIncorrecta2 eIncorrecta: textoIncorrecta3
	|pregunta|
	pregunta := (self new) conTexto: unTexto yRespuestas: 
		{ RespuestaCorrecta conTexto: textoCorrecta },
		({ textoCorrecta. textoIncorrecta1. textoIncorrecta2. textoIncorrecta3 } collect: [ :t | RespuestaIncorrecta conTexto: t ]).
		
	^pregunta! !

!Pregunta methodsFor: 'accessors' stamp: 'FedericoAloi 11/18/2015 16:58'!
algunaRespuestaIncorrecta
	^respuestas last! !

!Pregunta methodsFor: 'initialization' stamp: 'FedericoAloi 11/18/2015 16:50'!
conTexto: unTexto yRespuestas: unasRespuestas
	texto := unTexto.
	respuestas := OrderedCollection new.
	respuestas addAll: unasRespuestas ! !

!Pregunta methodsFor: 'accessors' stamp: 'FedericoAloi 11/18/2015 16:47'!
respuestaCorrecta
	^respuestas first! !

Object subclass: #Respuesta
	instanceVariableNames: 'texto'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Obj1-preguntados-model'!

!Respuesta class methodsFor: 'initialization' stamp: 'FedericoAloi 11/18/2015 11:00'!
conTexto: unTexto
	^(self new) conTexto: unTexto ; yourself! !

!Respuesta methodsFor: 'initialization' stamp: 'FedericoAloi 11/18/2015 11:00'!
conTexto: unTexto
	texto := unTexto ! !

Respuesta subclass: #RespuestaCorrecta
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Obj1-preguntados-model'!

!RespuestaCorrecta methodsFor: 'public' stamp: 'FedericoAloi 11/18/2015 16:55'!
fueElegidaEn: unTurno 
	unTurno preguntaRespondidaCorrectamente! !

Respuesta subclass: #RespuestaIncorrecta
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Obj1-preguntados-model'!

!RespuestaIncorrecta methodsFor: 'public' stamp: 'FedericoAloi 11/18/2015 16:59'!
fueElegidaEn: unTurno 
	unTurno preguntaRespondidaIncorrectamente ! !

Object subclass: #Turno
	instanceVariableNames: 'jugadorActual jugadorSiguiente etapa partida'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Obj1-preguntados-model'!

!Turno commentStamp: '<historical>' prior: 0!
Soy un turno en una partida. !

!Turno methodsFor: 'public' stamp: 'FedericoAloi 11/18/2015 12:04'!
avanzar
	etapa avanzarEn: self! !

!Turno methodsFor: 'public' stamp: 'FedericoAloi 11/24/2015 23:34'!
cambiarEtapaA: unaEtapa
	unaEtapa reiniciarPara: self.
	etapa := unaEtapa! !

!Turno methodsFor: 'accessors' stamp: 'FedericoAloi 11/18/2015 12:08'!
categorias
	^partida categorias! !

!Turno methodsFor: 'accesing' stamp: 'ArielAlvarez 10/28/2015 01:44'!
etapa
	^etapa! !

!Turno methodsFor: 'private' stamp: 'FedericoAloi 11/18/2015 16:55'!
incrementarPuntaje
	puntaje := puntaje + 1! !

!Turno methodsFor: 'initialization' stamp: 'FedericoAloi 11/25/2015 00:13'!
inicializarConActual: aJugador ySiguiente: aJugador2 enPartida: unaPartida
	jugadorActual := aJugador.
	jugadorSiguiente := aJugador2.
	partida := unaPartida.
	self cambiarEtapaA: EtapaGiroDeRuleta.
	^self! !

!Turno methodsFor: 'public' stamp: 'ArielAlvarez 10/27/2015 21:44'!
jugador
	^jugadorActual ! !

!Turno methodsFor: 'accessors' stamp: 'FedericoAloi 11/19/2015 16:47'!
jugadorActual
	^ jugadorActual! !

!Turno methodsFor: 'accessors' stamp: 'FedericoAloi 11/19/2015 16:46'!
jugadorSiguiente
	^ jugadorSiguiente! !

!Turno methodsFor: 'accessors' stamp: 'FedericoAloi 11/24/2015 22:54'!
pregunta
	^ etapa pregunta! !

!Turno methodsFor: 'public' stamp: 'FedericoAloi 11/24/2015 23:05'!
preguntaRespondidaCorrectamente
	self avanzar! !

!Turno methodsFor: 'public' stamp: 'FedericoAloi 11/19/2015 16:46'!
preguntaRespondidaIncorrectamente
	partida siguienteTurno
	! !

!Turno methodsFor: 'public' stamp: 'FedericoAloi 11/18/2015 16:54'!
responderPreguntaCon: unaRespuesta
	unaRespuesta fueElegidaEn: self! !
